# This script is not intended to be executed directly.  It is sourced by test-runner.sh and most functions you see here are defined in test-tools.sh
# The variables EXENAME, EXEBASE, OKDIR, and EXEDIR are defined externally.

beginTestBlock  # Begin a group of tests.
runMake -r @EXE  # run `make` for the main exe and any other listed programs
EXT=.ct  # set extension for @OKFILE and @OUTFILE placeholders (defaults for runDiff)

initRef 'general_without_options' _WO # initialize variables of the form *_WO (e.g. OUT_WO, OK_WO  etc) to point to the 'without_options' test files because these are used by multiple other tests.

# Test TurboFold_without_options_singly.
# Note that the general test has a mode specified of MEA; MEA is the default mode.
initTest 'general_without_options_singly'
echo "Seq1 = testFiles/testFile_ec5s.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_ca5s.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_5s_8.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
echo "Mode = MEA" >> "$TEST.conf"
if [[ $SMP ]]; then echo "Processors = 2" >> "$TEST.conf"; fi;
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE_WO}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE_WO}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE_WO}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_without_options_groups.
# Note that the general test has a mode specified of MEA; MEA is the default mode.
initTest 'general_without_options_groups'
echo "InSeq = {testFiles/testFile_ec5s.seq;testFiles/testFile_ca5s.seq;testFiles/testFile_5s_8.seq;}" > "$TEST.conf"
echo "OutCT = {${OUT}_seq1.ct;${OUT}_seq2.ct;${OUT}_seq3.ct;}" >> "$TEST.conf"
echo "Mode = MEA" >> "$TEST.conf"
if [[ $SMP ]]; then echo "Processors = 2" >> "$TEST.conf"; fi;
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE_WO}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE_WO}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE_WO}_seq3_OK.ct" 'seq3'
endTest

# Test an alternate TurboFold_general_without_options.
# Note that the general test has a mode specified of MEA; MEA is the default mode.
# Note also that these alternate test files are used to test ProbKnot mode only.
# This alternate test is needed to ensure that the ProbKnot_without_options test is different from a default test where ProbKnot mode isn't specified.
initTest 'general_without_options_alternate'
echo "Seq1 = testFiles/testFile_met-vol.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_met-fer.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_met-the.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_general_gamma_option.
# Note that the general test has a mode specified of MEA; MEA is the default mode.
initTest 'general_gamma_option'
echo "Seq1 = testFiles/testFile_ec5s.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_ca5s.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_5s_8.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
echo "Gamma = 0.9" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_general_iterations_option.
# Note that the general test has a mode specified of MEA; MEA is the default mode.
initTest 'general_iterations_option'
echo "Seq1 = testFiles/testFile_ec5s.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_ca5s.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_5s_8.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
echo "Iterations = 1" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_general_shape_option.
# Note that the general test has a mode specified of MEA; MEA is the default mode.
initTest 'general_shape_option'
echo "Seq1 = testFiles/testFile_ec5s.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_ca5s.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_5s_8.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
echo "SHAPE1 = testFiles/testFile_random_dummy.shape" >> "$TEST.conf"
echo "SHAPE2 = testFiles/testFile_random_dummy.shape" >> "$TEST.conf"
echo "SHAPE3 = testFiles/testFile_random_dummy.shape" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_general_shape_intercept_option.
# Note that the general test has a mode specified of MEA; MEA is the default mode.
initTest 'general_shape_intercept_option'
echo "Seq1 = testFiles/testFile_ec5s.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_ca5s.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_5s_8.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
echo "SHAPE1 = testFiles/testFile_random_dummy.shape" >> "$TEST.conf"
echo "SHAPE2 = testFiles/testFile_random_dummy.shape" >> "$TEST.conf"
echo "SHAPE3 = testFiles/testFile_random_dummy.shape" >> "$TEST.conf"
echo "SHAPEintercept = 0.1" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_general_shape_slope_option.
# Note that the general test has a mode specified of MEA; MEA is the default mode.
initTest 'general_shape_slope_option'
echo "Seq1 = testFiles/testFile_ec5s.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_ca5s.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_5s_8.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
echo "SHAPE1 = testFiles/testFile_random_dummy.shape" >> "$TEST.conf"
echo "SHAPE2 = testFiles/testFile_random_dummy.shape" >> "$TEST.conf"
echo "SHAPE3 = testFiles/testFile_random_dummy.shape" >> "$TEST.conf"
echo "SHAPEslope = 0.1" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_general_temperature_option.
# Note that the general test has a mode specified of MEA; MEA is the default mode.
initTest 'general_temperature_option'
echo "Seq1 = testFiles/testFile_ec5s.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_ca5s.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_5s_8.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
echo "Temperature = 330" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# If the executable is SMP, test the processors option.
if [[ $SMP ]]; then
initTest 'processors_option'
echo "Seq1 = testFiles/testFile_ec5s.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_ca5s.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_5s_8.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
echo "Processors = 3" >> "$TEST.conf";
echo "Mode = MEA" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE_WO}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE_WO}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE_WO}_seq3_OK.ct" 'seq3'
endTest
fi

# Test TurboFold_MEA-mode_without_options.
initTest 'MEA-mode_without_options'
echo "Seq1 = testFiles/testFile_ec5s.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_ca5s.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_5s_8.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE_WO}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE_WO}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE_WO}_seq3_OK.ct" 'seq3'
endTest

# Test an alternate TurboFold_MEA-mode_without_options.
# These test files are not used for all MEA mode tests, just max structures, percent difference, and window size.
initTest 'MEA-mode_without_options_alternate'
echo "Seq1 = testFiles/testFile_RA7680.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_RD0260.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_RD0500.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_MEA-mode_gamma_option.
initTest 'MEA-mode_gamma_option'
echo "Seq1 = testFiles/testFile_ec5s.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_ca5s.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_5s_8.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
echo "MeaGamma = 0.2" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_MEA-mode_max_structures_option.
initTest 'MEA-mode_max_structures_option'
echo "Seq1 = testFiles/testFile_RA7680.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_RD0260.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_RD0500.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
echo "MaxStructures = 5" >> "$TEST.conf"
echo "Window = 0" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_MEA-mode_percent_difference_option.
initTest 'MEA-mode_percent_difference_option'
echo "Seq1 = testFiles/testFile_RA7680.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_RD0260.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_RD0500.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
echo "MaxPercent = 4" >> "$TEST.conf"
echo "Window = 0" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_MEA-mode_window_size_option.
initTest 'MEA-mode_window_size_option'
echo "Seq1 = testFiles/testFile_RA7680.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_RD0260.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_RD0500.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = MEA" >> "$TEST.conf"
echo "Window = 0" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_ProbKnot-mode_without_options.
initTest 'ProbKnot-mode_without_options'
echo "Seq1 = testFiles/testFile_met-vol.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_met-fer.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_met-the.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = ProbKnot" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_ProbKnot-mode_iterations_option.
initTest 'ProbKnot-mode_iterations_option'
echo "Seq1 = testFiles/testFile_met-vol.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_met-fer.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_met-the.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = ProbKnot" >> "$TEST.conf"
echo "PkIterations = 10" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_ProbKnot-mode_min_helix_length_option.
initTest 'ProbKnot-mode_min_helix_length_option'
echo "Seq1 = testFiles/testFile_met-vol.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_met-fer.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_met-the.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = ProbKnot" >> "$TEST.conf"
echo "MinHelixLength = 1" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_Threshold-mode_without_options.
initTest 'Threshold-mode_without_options'
echo "Seq1 = testFiles/testFile_ec5s.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_ca5s.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_5s_8.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = Threshold" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

# Test TurboFold_Threshold-mode_threshold_option.
initTest 'Threshold-mode_threshold_option'
echo "Seq1 = testFiles/testFile_ec5s.seq" > "$TEST.conf"
echo "Seq2 = testFiles/testFile_ca5s.seq" >> "$TEST.conf"
echo "Seq3 = testFiles/testFile_5s_8.seq" >> "$TEST.conf"
echo "CT1 = ${OUT}_seq1.ct" >> "$TEST.conf"
echo "CT2 = ${OUT}_seq2.ct" >> "$TEST.conf"
echo "CT3 = ${OUT}_seq3.ct" >> "$TEST.conf"
echo "SequenceNumber = 3" >> "$TEST.conf"
if [[ $1 = "TurboFold-smp" ]]; then echo "Processors = 2" >> "$TEST.conf"; fi
echo "Mode = Threshold" >> "$TEST.conf"
echo "Threshold = 0.92" >> "$TEST.conf"
runTest @EXE "$TEST.conf"
runDiff "${OUT}_seq1.ct" "${OKBASE}_seq1_OK.ct" 'seq1'
runDiff "${OUT}_seq2.ct" "${OKBASE}_seq2_OK.ct" 'seq2'
runDiff "${OUT}_seq3.ct" "${OKBASE}_seq3_OK.ct" 'seq3'
endTest

endTestBlock # End a group of tests. Also cleans up orphaned files etc.

